@@ -16,7 +16,7 @@ import sys
 import kirchhoff.init_crystal as init_crystal
 import kirchhoff.init_random as init_random
 # custom output functions
-import draw_networkx as dx
+import kirchhoff.draw_networkx as dx
 
 def initialize_circuit_from_networkx(input_graph):
 
